<?php
require_once('../tcpdf/tcpdf.php');
include '../includes/db_connect.php';

if (isset($_GET['id'])) {
    $id_compra = intval($_GET['id']);

    // Obtener los datos de la compra
    $sql = "SELECT id, id_rifa, numeros_comprados, nombre, apellido, cedula, telefono, correo, estado, monto_total FROM compras_rifa WHERE id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $id_compra);
    $stmt->execute();
    $result = $stmt->get_result();
    $compra = $result->fetch_assoc();

    if (!$compra) {
        die("Compra no encontrada.");
    }

    // Crear un nuevo PDF
    $pdf = new TCPDF();
    $pdf->SetCreator(PDF_CREATOR);
    $pdf->SetTitle("Recibo de Transacción");
    $pdf->SetMargins(15, 20, 15);
    $pdf->AddPage();

    // Agregar encabezado centrado
    $pdf->SetFont('helvetica', 'B', 18);
    $pdf->SetTextColor(0, 0, 0); // Negro
    $pdf->Cell(0, 10, " La Casa De Las Rifas ", 0, 1, 'C');
    $pdf->Ln(5); // Espacio después del encabezado

    // Agregar logo en la parte superior izquierda
    $logo_path = '../assets/img/logo_pdf.png'; // Ajusta la ruta del logo
    if (file_exists($logo_path)) {
        $pdf->Image($logo_path, 15, 20, 40, 0, 'PNG'); // X, Y, Ancho, Alto, Formato (Y cambiado a 20)
    }

    // Agregar logo en la parte superior derecha
    $pdf->Image($logo_path, 160, 20, 40, 0, 'PNG'); // X, Y, Ancho, Alto, Formato (Y cambiado a 20)
    $pdf->Ln(20); // Espaciado después del logo

    // Estilos del título
    $pdf->SetFont('helvetica', 'B', 16);
    $pdf->SetTextColor(0, 0, 0); // Negro
    $pdf->Cell(0, 10, "Recibo de Transacción", 0, 1, 'C');

    // Línea de separación
    $pdf->SetDrawColor(0, 0, 0); // Negro
    $pdf->SetLineWidth(0.5);
    $pdf->Line(15, $pdf->GetY(), 195, $pdf->GetY());
    $pdf->Ln(10);

    // Contenido del PDF con colores
    $pdf->SetFont('helvetica', '', 12);
    $pdf->SetTextColor(0, 0, 0); // Negro

    // Definir datos con estilos
    $datos = [
        'ID de Compra' => str_pad($compra['id'], 8, '0', STR_PAD_LEFT), // Formatear ID a 8 dígitos
        'ID de Rifa' => str_pad($compra['id_rifa'], 8, '0', STR_PAD_LEFT), // Formatear ID Rifa a 8 dígitos
        'Números Comprados' => $compra['numeros_comprados'],
        'Nombre' => $compra['nombre'] . ' ' . $compra['apellido'],
        'Cédula' => $compra['cedula'],
        'Teléfono' => $compra['telefono'],
        'Correo' => $compra['correo'],
        'Estado' => $compra['estado'],
        'Monto Total en $' => number_format($compra['monto_total'], 2)
    ];

    // Mostrar datos con subtítulos alineados a la izquierda y contenido a la derecha
    foreach ($datos as $key => $value) {
        $pdf->SetTextColor(0, 0, 0); // Negro para títulos
        $pdf->SetFont('helvetica', 'B', 12);
        $pdf->Cell(90, 8, $key . ":", 0, 0, 'L'); // Subtítulo alineado a la izquierda

        // Si el estado es "en espera", se pone en naranja, si es "confirmado", en verde
        if ($key == 'Estado') {
            if ($value == 'espera') {
                $pdf->SetTextColor(255, 165, 0); // Naranja
            } elseif ($value == 'confirmado') {
                $pdf->SetTextColor(0, 255, 0); // Verde
            }
        }

        $pdf->SetFont('helvetica', '', 12);
        $pdf->Cell(0, 8, $value, 0, 1, 'R'); // Contenido alineado a la derecha
        $pdf->SetTextColor(0, 0, 0); // Restaurar color de texto a negro después de cada campo
    }

    // Agregar texto pequeño debajo del monto total
    $pdf->SetFont('helvetica', '', 10);
    $pdf->SetTextColor(0, 0, 0); // Negro
    $pdf->Ln(5); // Espaciado después del monto total
    $pdf->Cell(0, 8, "pagaturifa.com", 0, 1, 'C');

    // Descargar el PDF
    $pdf->Output('Recibo_Transaccion_' . $compra['id'] . '.pdf', 'I');
} else {
    echo "ID de compra no especificado.";
}
?>
