<?php
session_start();

// Verificar si el usuario está autenticado y tiene privilegios
if (!isset($_SESSION['usuario_id']) || $_SESSION['usuario_rol'] !== 'admin') {
    header("Location: ../login.php"); // Redirigir al login si no tiene privilegios
    exit();
}

include '../../includes/db_connect.php';

// Cargar PHPMailer manualmente
require '../../phpmailer/src/PHPMailer.php';
require '../../phpmailer/src/Exception.php';
require '../../phpmailer/src/SMTP.php';

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

// Procesar la subida del comprobante
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['subir_comprobante'])) {
    $id_compra = intval($_POST['id_compra']);
    $comprobante_text = htmlspecialchars($_POST['comprobante_text']);
    $comprobante_file = $_FILES['comprobante_file'];

    if ($comprobante_file['error'] === UPLOAD_ERR_OK) {
        // Procesar la subida del archivo
        $upload_dir = '../../pagos_ima/';
        $file_name = basename($comprobante_file['name']);
        $file_path = $upload_dir . $file_name;

        if (move_uploaded_file($comprobante_file['tmp_name'], $file_path)) {
            // Actualizar la base de datos con el nombre del archivo
            $sql = "UPDATE compras_rifa SET foto_comprobante = ? WHERE id = ?";
            $stmt = $conn->prepare($sql);
            if ($stmt) {
                $stmt->bind_param("si", $file_name, $id_compra);
                if ($stmt->execute()) {
                    $mensaje = "Comprobante subido correctamente.";
                } else {
                    $error = "Error al actualizar el comprobante: " . $stmt->error;
                }
                $stmt->close();
            } else {
                $error = "Error en la preparación de la consulta: " . $conn->error;
            }
        } else {
            $error = "Error al mover el archivo subido.";
        }
    } elseif (!empty($comprobante_text)) {
        // Actualizar la base de datos con el número de referencia
        $sql = "UPDATE compras_rifa SET foto_comprobante = ? WHERE id = ?";
        $stmt = $conn->prepare($sql);
        if ($stmt) {
            $stmt->bind_param("si", $comprobante_text, $id_compra);
            if ($stmt->execute()) {
                $mensaje = "Número de referencia actualizado correctamente.";
            } else {
                $error = "Error al actualizar el número de referencia: " . $stmt->error;
            }
            $stmt->close();
        } else {
            $error = "Error en la preparación de la consulta: " . $conn->error;
        }
    } else {
        $error = "Debes subir un archivo o ingresar un número de referencia.";
    }
}

// Inicializar variables
$compras = [];
$mensaje = '';
$error = '';
$busqueda = '';

// Procesar el cambio de estado de los números
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['cambiar_estado'])) {
    $id_compra = intval($_POST['id_compra']);
    $nuevo_estado = htmlspecialchars($_POST['nuevo_estado']);

    // Validar el estado
    if (!in_array($nuevo_estado, ['espera', 'confirmado', 'rechazado'])) {
        $error = "Estado no válido.";
    } else {
        // Si el estado es "rechazado", eliminamos la compra
        if ($nuevo_estado == 'rechazado') {
            // Eliminar el registro de la compra de la base de datos
            $sql = "DELETE FROM compras_rifa WHERE id = ?";
            $stmt = $conn->prepare($sql);
            if (!$stmt) {
                $error = "Error en la preparación de la consulta para eliminar: " . $conn->error;
            } else {
                $stmt->bind_param("i", $id_compra);
                if ($stmt->execute()) {
                    $mensaje = "Compra eliminada correctamente.";
                } else {
                    $error = "Error al eliminar la compra: " . $stmt->error;
                }
                $stmt->close();
            }
        } else {
            // Si no es "rechazado", solo actualizamos el estado
            $sql = "UPDATE compras_rifa SET estado = ? WHERE id = ?";
            $stmt = $conn->prepare($sql);
            if (!$stmt) {
                $error = "Error en la preparación de la consulta para actualizar el estado: " . $conn->error;
            } else {
                $stmt->bind_param("si", $nuevo_estado, $id_compra);

                if ($stmt->execute()) {
                    $mensaje = "Estado actualizado con éxito.";

                    // Si el estado es "confirmado", enviar el correo
                    if ($nuevo_estado == 'confirmado') {
                        // Obtener los datos de la compra
                        $sql_compra = "SELECT correo, nombre, apellido FROM compras_rifa WHERE id = ?";
                        $stmt_compra = $conn->prepare($sql_compra);
                        if ($stmt_compra) {
                            $stmt_compra->bind_param("i", $id_compra);
                            $stmt_compra->execute();
                            $result_compra = $stmt_compra->get_result();
                            if ($result_compra->num_rows > 0) {
                                $row_compra = $result_compra->fetch_assoc();
                                $correo = $row_compra['correo'];
                                $nombre = $row_compra['nombre'];
                                $apellido = $row_compra['apellido'];

                                // Ruta al script que genera el PDF
                                $pdf_script_url = "http://pagaturifa.com/includes/generar_recibo.php?id=$id_compra";

                                // Crear un archivo temporal para almacenar el PDF
                                $temp_pdf_path = tempnam(sys_get_temp_dir(), 'recibo_') . '.pdf';

                                // Ejecutar el script y guardar la salida en el archivo temporal
                                file_put_contents($temp_pdf_path, file_get_contents($pdf_script_url));

                                // Verificar si el archivo temporal se creó correctamente
                                if (!file_exists($temp_pdf_path)) {
                                    $error .= " No se pudo generar el archivo PDF.";
                                } else {
                                    // Inicializar PHPMailer
                                    $mail = new PHPMailer(true);

                                    try {
                                        // Configuración del servidor SMTP
                                        $mail->isSMTP();
                                        $mail->Host = 'mail.spacemail.com'; // Cambia esto por tu servidor SMTP
                                        $mail->SMTPAuth = true;
                                        $mail->Username = 'principal@pagaturifa.com'; // Cambia esto por tu correo
                                        $mail->Password = 'C0ab5449-566A-4333-9733-427933540171'; // Cambia esto por tu contraseña
                                        $mail->SMTPSecure = PHPMailer::ENCRYPTION_SMTPS;
                                        $mail->Port = 465; // Puerto SMTP

                                        // Remitente y destinatario
                                        $mail->setFrom('principal@pagaturifa.com', 'pagaturifa.com');
                                        $mail->addAddress($correo, "$nombre $apellido");

                                        // Adjuntar el PDF
                                        $mail->addAttachment($temp_pdf_path, 'recibo.pdf');

                                        // Contenido del correo
                                        $mail->isHTML(true);
                                        $mail->Subject = 'La compra de tus numeros ha sido aprobada: *ver pdf*';
                                        $mail->Body    = "Hola $nombre $apellido,<br><br>Tu compra ha sido confirmada. Adjunto encontrarás el recibo de tu compra.<br><br>Saludos,<br>Tu empresa";

                                        // Enviar el correo
                                        $mail->send();
                                        $mensaje .= " Correo enviado correctamente.";
                                    } catch (Exception $e) {
                                        $error .= " Error al enviar el correo: " . $mail->ErrorInfo;
                                    }

                                    // Eliminar el archivo temporal
                                    if (file_exists($temp_pdf_path)) {
                                        unlink($temp_pdf_path);
                                    }
                                }
                            }
                            $stmt_compra->close();
                        }
                    }
                } else {
                    $error = "Error al actualizar el estado: " . $stmt->error;
                }

                $stmt->close();
            }
        }
    }
}

// Procesar la búsqueda
if ($_SERVER['REQUEST_METHOD'] === 'GET' && isset($_GET['busqueda'])) {
    $busqueda = htmlspecialchars($_GET['busqueda']);

    // Obtener todas las compras de la tabla compras_rifa con filtro de búsqueda
    $sql = "SELECT id, id_rifa, numeros_comprados, nombre, apellido, cedula, telefono, correo, region, ciudad, foto_comprobante, monto_total 
            FROM compras_rifa 
            WHERE id_rifa LIKE ? 
               OR nombre LIKE ? 
               OR apellido LIKE ? 
               OR cedula LIKE ? 
               OR telefono LIKE ? 
               OR correo LIKE ? 
               OR region LIKE ? 
               OR ciudad LIKE ?";

    $stmt = $conn->prepare($sql);
    if (!$stmt) {
        $error = "Error en la preparación de la consulta: " . $conn->error;
    } else {
        $param_busqueda = "%$busqueda%";
        $stmt->bind_param("ssssssss", $param_busqueda, $param_busqueda, $param_busqueda, $param_busqueda, $param_busqueda, $param_busqueda, $param_busqueda, $param_busqueda);

        if ($stmt->execute()) {
            $result = $stmt->get_result();
            if ($result->num_rows > 0) {
                while ($row = $result->fetch_assoc()) {
                    $compras[] = $row;
                }
            }
        } else {
            $error = "Error al ejecutar la consulta: " . $stmt->error;
        }

        $stmt->close();
    }
} else {
    // Obtener todas las compras de la tabla compras_rifa sin filtro
    $sql = "SELECT id, id_rifa, numeros_comprados, nombre, apellido, cedula, telefono, correo, region, ciudad, foto_comprobante, monto_total 
            FROM compras_rifa";

    $result = $conn->query($sql);

    if ($result) {
        if ($result->num_rows > 0) {
            while ($row = $result->fetch_assoc()) {
                $compras[] = $row;
            }
        }
    } else {
        $error = "Error al ejecutar la consulta: " . $conn->error;
    }
}

$conn->close();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Tabla de Clientes</title>
    <link rel="stylesheet" href="../../assets/css/tabla.css">
    <style>
        body {
            zoom: 0.8; /* 80% */
        }

        /* Estilos para el modal */
        .modal {
            display: none;
            position: fixed;
            z-index: 1;
            left: 0;
            top: 0;
            width: 100%;
            height: 100%;
            overflow: auto;
            background-color: rgb(0,0,0);
            background-color: rgba(0,0,0,0.9);
        }

        .modal-content {
            margin: auto;
            display: block;
            width: 80%;
            max-width: 700px;
        }

        .close {
            position: absolute;
            top: 15px;
            right: 35px;
            color: #fff;
            font-size: 40px;
            font-weight: bold;
            transition: 0.3s;
        }

        .close:hover,
        .close:focus {
            color: #bbb;
            text-decoration: none;
            cursor: pointer;
        }

        /* Estilo de la imagen al hacer clic */
        img {
            cursor: pointer;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <h2>Registro de Compras de Rifa</h2>

        <!-- Formulario de búsqueda -->
        <form method="GET" action="" class="mb-4">
            <div class="input-group">
                <input type="text" name="busqueda" class="form-control" placeholder="Buscar por número de rifa, nombre, apellido, cédula, teléfono o correo" value="<?php echo $busqueda; ?>">
                <button type="submit" class="btn btn-primary">Buscar</button>
            </div>
        </form>

        <?php if ($mensaje): ?>
            <div class="alert alert-success"><?php echo $mensaje; ?></div>
        <?php endif; ?>
        <?php if ($error): ?>
            <div class="alert alert-danger"><?php echo $error; ?></div>
        <?php endif; ?>

        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>ID Rifa</th>
                    <th>Números Comprados</th>
                    <th>Nombre</th>
                    <th>Apellido</th>
                    <th>Cédula</th>
                    <th>Teléfono</th>
                    <th>Correo</th>
                    <th>Región</th>
                    <th>Ciudad</th>
                    <th>Comprobante</th>
                    <th>Monto Total</th>
                    <th>Acciones</th>
                </tr>
            </thead>
            <tbody>
                <?php if (empty($compras)): ?>
                    <tr>
                        <td colspan="13" class="text-center">No se encontraron resultados.</td>
                    </tr>
                <?php else: ?>
                    <?php foreach ($compras as $compra): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($compra['id']); ?></td>
                            <td><?php echo htmlspecialchars($compra['id_rifa']); ?></td>
                            <td><?php echo htmlspecialchars($compra['numeros_comprados']); ?></td>
                            <td><?php echo htmlspecialchars($compra['nombre']); ?></td>
                            <td><?php echo htmlspecialchars($compra['apellido']); ?></td>
                            <td><?php echo htmlspecialchars($compra['cedula']); ?></td>
                            <td><?php echo htmlspecialchars($compra['telefono']); ?></td>
                            <td><?php echo htmlspecialchars($compra['correo']); ?></td>
                            <td><?php echo htmlspecialchars($compra['region']); ?></td>
                            <td><?php echo htmlspecialchars($compra['ciudad']); ?></td>
                            <td>
                                <?php
                                $comprobante = $compra['foto_comprobante'];
                                if ($comprobante) {
                                    // Verificar si el comprobante es una imagen (por extensión)
                                    $extensiones_imagen = ['jpg', 'jpeg', 'png', 'gif', 'bmp'];
                                    $extension = strtolower(pathinfo($comprobante, PATHINFO_EXTENSION));
                                    if (in_array($extension, $extensiones_imagen)) {
                                        // Mostrar la imagen
                                        echo '<img src="../../pagos_ima/' . htmlspecialchars($comprobante) . '" alt="Comprobante" style="max-width: 100px; height: auto;">';
                                    } else {
                                        // Mostrar el valor numérico o texto
                                        echo htmlspecialchars($comprobante);
                                    }
                                } else {
                                    // Mostrar el formulario para subir un comprobante o ingresar un número de referencia
                                    echo '<form method="POST" action="" enctype="multipart/form-data">';
                                    echo '<input type="hidden" name="id_compra" value="' . htmlspecialchars($compra['id']) . '">';
                                    echo '<input type="file" name="comprobante_file" accept="image/*">';
                                    echo '<input type="text" name="comprobante_text" placeholder="Número de referencia">';
                                    echo '<button type="submit" name="subir_comprobante" class="btn btn-primary btn-sm">Subir</button>';
                                    echo '</form>';
                                }
                                ?>
                            </td>
                            <td><?php echo htmlspecialchars($compra['monto_total']); ?></td>
                            <td>
                                <a href="../../includes/generar_recibo.php?id=<?php echo $compra['id']; ?>" target="_blank" class="btn btn-secondary btn-sm">Recibo</a>
                            </td>
                            <td>
                                <form method="POST" action="">
                                    <input type="hidden" name="id_compra" value="<?php echo htmlspecialchars($compra['id']); ?>">
                                    <select name="nuevo_estado">
                                        <option value="espera" <?php echo $compra['estado'] == 'espera' ? 'selected' : ''; ?>>Espera</option>
                                        <option value="confirmado" <?php echo $compra['estado'] == 'confirmado' ? 'selected' : ''; ?>>Confirmado</option>
                                        <option value="rechazado" <?php echo $compra['estado'] == 'rechazado' ? 'selected' : ''; ?>>Rechazado</option>
                                    </select>
                                    <button type="submit" name="cambiar_estado" class="btn btn-primary btn-sm">Cambiar</button>
                                </form>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <!-- The Modal -->
    <div id="myModal" class="modal">
        <span class="close">&times;</span>
        <img class="modal-content" id="img01">
    </div>

    <script>
        // Obtener el modal
        var modal = document.getElementById("myModal");

        // Obtener la imagen y el elemento modal
        var img = document.querySelectorAll("img");
        var modalImg = document.getElementById("img01");

        img.forEach(function(el) {
            el.onclick = function() {
                modal.style.display = "block";
                modalImg.src = this.src;
            }
        });

        // Obtener el elemento <span> que cierra el modal
        var span = document.getElementsByClassName("close")[0];

        // Cuando el usuario haga clic en <span> (x), cerrar el modal
        span.onclick = function() {
            modal.style.display = "none";
        }
    </script>
</body>
</html>