<?php
include '../includes/db_connect.php';

// Obtener el ID de la rifa desde la URL
$id_rifa = isset($_GET['id']) ? intval($_GET['id']) : 0;

if ($id_rifa === 0) {
    die("Rifa no especificada.");
}

// Consulta para obtener los detalles de la rifa activa
$sqlRifa = "SELECT nombre_rifa, premio, cantidad_numeros, precio_unitario, fecha_sorteo, minimo_numeros 
            FROM rifas_activas 
            WHERE id = ?";
$stmtRifa = $conn->prepare($sqlRifa);
$stmtRifa->bind_param("i", $id_rifa);
$stmtRifa->execute();
$resultRifa = $stmtRifa->get_result();

if ($resultRifa->num_rows === 0) {
    die("Rifa no encontrada.");
}

$rowRifa = $resultRifa->fetch_assoc();
$nombre_rifa = $rowRifa['nombre_rifa'];
$premio_principal = $rowRifa['premio'];
$cantidad_numeros = $rowRifa['cantidad_numeros'];
$precio_unitario = $rowRifa['precio_unitario'];
$fecha_sorteo = $rowRifa['fecha_sorteo'];
$minimo_numeros = $rowRifa['minimo_numeros']; // Nuevo campo

// Consulta para obtener los números ocupados (incluyendo confirmados)
$sql = "SELECT numeros_comprados FROM compras_rifa WHERE id_rifa = ? AND estado IN ('espera', 'confirmado')";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $id_rifa);
$stmt->execute();
$result = $stmt->get_result();

$numeros_ocupados = [];
while ($row = $result->fetch_assoc()) {
    $numeros = explode(",", $row["numeros_comprados"]);
    $numeros_ocupados = array_merge($numeros_ocupados, $numeros);
}

// Formatear números ocupados a 4 dígitos
$numeros_ocupados = array_map(function($num) {
    return str_pad($num, 4, '0', STR_PAD_LEFT);
}, $numeros_ocupados);

$conn->close();
$numeros_ocupados_json = json_encode($numeros_ocupados);
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo htmlspecialchars($nombre_rifa); ?></title>
    <link rel="stylesheet" href="../assets/css/style_rifa.css">
    <style>
        .ocupado {
            background-color: red !important;
            cursor: not-allowed;
        }
        .seleccionado {
            background-color: black !important;
        }
        .controls {
            margin-bottom: 20px;
        }
        #search {
            padding: 10px;
            width: 200px;
            margin-right: 10px;
        }
        .pagination {
            display: inline-block;
        }
        .pagination button {
            padding: 10px;
            margin: 0 5px;
            cursor: pointer;
        }
        .numero {
            display: inline-block;
            width: 50px;
            height: 50px;
            line-height: 50px;
            text-align: center;
            border: 1px solid #ccc;
            margin: 5px;
            cursor: pointer;
        }
        .clear-search {
            padding: 10px;
            cursor: pointer;
            background-color: #f0f0f0;
            border: 1px solid #ccc;
        }
        
        .boton-pagar{
            width:120px;
            height:80px;
            border-radius:15px;
            border:none;
        }
        @media(max-width:600px){
            .boton-pagar{
                opacity:0.8;
            }
        }
        
        .minimo-numeros {
        font-size: 16px;
        color: #333;
        margin-bottom: 10px;
    }
    </style>
</head>
<body>
    <div class="container">
        <!-- Agrega el botón de pagar -->
        <button onclick="scrollToEnd()" class="boton-pagar" style="position:fixed; top:10px; left:10px;">Pagar</button>
        
        <h1><?php echo htmlspecialchars($nombre_rifa); ?></h1>
        <h2>GRAN SORTEO</h2>
        <div class="premio pulse">¡GÁNATE:  <?php echo htmlspecialchars($premio_principal); ?>!</div>
        <div class="precio">Precio por número: $<?php echo htmlspecialchars($precio_unitario); ?></div>
        <div class="minimo-numeros">Mínimo de números a comprar: <?php echo htmlspecialchars($minimo_numeros); ?></div>

        <!-- Controles de búsqueda y paginación -->
        <div class="controls">
            <input type="text" id="search" placeholder="Buscar número...">
            <button class="clear-search" onclick="clearSearch()">Limpiar</button>
            <div class="pagination">
                <button id="prev-page">Anterior</button>
                <span id="page-info"></span>
                <button id="next-page">Siguiente</button>
            </div>
        </div>

        <!-- Tablero de números -->
        <div class="tablero">
            <?php
            for ($i = 1; $i <= $cantidad_numeros; $i++) {
                // Formato de 4 dígitos
                $numero = str_pad($i, 4, '0', STR_PAD_LEFT);
                echo "<div class='numero' data-numero='$numero'>$numero</div>";
            }
            ?>
        </div>

        <!-- Carrito de compras -->
        <div class="carrito">
            <h3>🛒 Carrito de Números</h3>
            <ul id="lista-carrito"></ul>
            <p id="total-precio">Total: $0</p>
        </div>
        <div class="fecha-sorteo">SORTEO EL <?php echo htmlspecialchars($fecha_sorteo); ?></div>

        <!-- Métodos de pago -->
        <div class="formulario-pago">
            <h3>Seleccione el método de pago</h3>
            <button onclick="pagarEnPagina()">Pagar en la Página</button>
            <button class="whatsapp" onclick="pagarPorWhatsApp()">Pagar por WhatsApp</button>
        </div>
    </div>

    <script>
        let numerosSeleccionados = [];
        let numerosOcupados = <?php echo $numeros_ocupados_json; ?>;
        let precioUnitario = <?php echo $precio_unitario; ?>;
        let currentPage = 1;
        const numbersPerPage = 100; // Números por página

        // Mostrar números de la página actual
        function showPage(page) {
            const numbers = document.querySelectorAll('.numero');
            const start = (page - 1) * numbersPerPage;
            const end = start + numbersPerPage;

            numbers.forEach((numero, index) => {
                if (index >= start && index < end) {
                    numero.style.display = 'inline-block';
                } else {
                    numero.style.display = 'none';
                }
            });

            document.getElementById('page-info').textContent = `Página ${page} de ${Math.ceil(numbers.length / numbersPerPage)}`;
        }

        // Buscar números
        function searchNumber() {
            const searchValue = document.getElementById('search').value;
            const numbers = document.querySelectorAll('.numero');

            if (searchValue === "") {
                showPage(currentPage); // Mostrar la página actual si no hay búsqueda
                return;
            }

            numbers.forEach(numero => {
                const num = numero.getAttribute('data-numero');
                if (num.includes(searchValue)) {
                    numero.style.display = 'inline-block';
                } else {
                    numero.style.display = 'none';
                }
            });
        }

        // Limpiar el input de búsqueda
        function clearSearch() {
            document.getElementById('search').value = "";
            showPage(currentPage); // Mostrar la página actual
        }

        // Actualizar el carrito
        function actualizarCarrito() {
            const listaCarrito = document.getElementById('lista-carrito');
            listaCarrito.innerHTML = '';
            let precioTotal = 0;

            numerosSeleccionados.forEach(numero => {
                const li = document.createElement('li');
                li.textContent = `Número: ${numero} - Precio: $${precioUnitario}`;
                listaCarrito.appendChild(li);
                precioTotal += precioUnitario;
            });

            document.getElementById('total-precio').textContent = `Total: $${precioTotal}`;
        }

        // Pagar en la página
        function pagarEnPagina() {
            if (numerosSeleccionados.length === 0) {
                alert("Debe seleccionar al menos un número.");
                return;
            }
            if (numerosSeleccionados.length < <?php echo $minimo_numeros; ?>) {
                alert(`Debes elegir al menos <?php echo $minimo_numeros; ?> números.`);
                return;
            }
            window.location.href = `../pages/pago_online.php?id_rifa=<?php echo $id_rifa; ?>&numeros=${numerosSeleccionados.join(',')}`;
        }
        
        // Pagar por WhatsApp
        function pagarPorWhatsApp() {
            if (numerosSeleccionados.length === 0) {
                alert("Debe seleccionar al menos un número.");
                return;
            }
            if (numerosSeleccionados.length < <?php echo $minimo_numeros; ?>) {
                alert(`Debes elegir al menos <?php echo $minimo_numeros; ?> números.`);
                return;
            }
            window.location.href = `../pages/compra_whatsapp.php?id_rifa=<?php echo $id_rifa; ?>&numeros=${numerosSeleccionados.join(',')}`;
        }

        // Inicializar eventos
        document.addEventListener("DOMContentLoaded", function () {
            showPage(currentPage);

            // Eventos de paginación
            document.getElementById('prev-page').addEventListener('click', () => {
                if (currentPage > 1) {
                    currentPage--;
                    showPage(currentPage);
                }
            });

            document.getElementById('next-page').addEventListener('click', () => {
                const numbers = document.querySelectorAll('.numero');
                if (currentPage < Math.ceil(numbers.length / numbersPerPage)) {
                    currentPage++;
                    showPage(currentPage);
                }
            });

            // Evento de búsqueda
            document.getElementById('search').addEventListener('input', searchNumber);

            // Eventos de selección de números
            document.querySelectorAll('.numero').forEach(numero => {
                let num = numero.getAttribute('data-numero');

                // Marcar números ocupados
                if (numerosOcupados.includes(num)) {
                    numero.classList.add('ocupado');
                    numero.style.pointerEvents = 'none'; // Deshabilitar clic
                } else {
                    // Permitir selección solo si el número no está ocupado
                    numero.addEventListener('click', () => {
                        if (numerosSeleccionados.includes(num)) {
                            numerosSeleccionados = numerosSeleccionados.filter(n => n !== num);
                            numero.classList.remove('seleccionado');
                        } else {
                            numerosSeleccionados.push(num);
                            numero.classList.add('seleccionado');
                        }
                        actualizarCarrito();
                    });
                }
            });
        });

        // Función para desplazar al final de la página
        function scrollToEnd() {
            window.scrollTo({
                top: document.body.scrollHeight,
                behavior: 'smooth'
            });
        }
    </script>
</body>
</html>